Package: microbenchmark
Title: Accurate Timing Functions
Description: Provides infrastructure to accurately measure and compare
        the execution time of R expressions.
Authors@R: c(person("Olaf", "Mersmann", role=c("aut")),
        person("Claudia", "Beleites", role=c("ctb")),
        person("Rainer", "Hurling", role=c("ctb")),
        person("Ari", "Friedman", role=c("ctb")),
        person(given=c("Joshua","M."), family="Ulrich", role="cre",
               email="josh.m.ulrich@gmail.com"))
URL: https://github.com/joshuaulrich/microbenchmark/
BugReports: https://github.com/joshuaulrich/microbenchmark/issues/
License: BSD_2_clause + file LICENSE
Depends: R (>= 3.2.0)
Imports: graphics, stats
Suggests: ggplot2, multcomp, RUnit
SystemRequirements: On a Unix-alike, one of the C functions
        mach_absolute_time (macOS), clock_gettime or gethrtime. If none
        of these is found, the obsolescent POSIX function gettimeofday
        will be tried.
ByteCompile: yes
Version: 1.5.0
NeedsCompilation: yes
Packaged: 2024-09-03 22:50:33 UTC; josh
Author: Olaf Mersmann [aut],
  Claudia Beleites [ctb],
  Rainer Hurling [ctb],
  Ari Friedman [ctb],
  Joshua M. Ulrich [cre]
Maintainer: Joshua M. Ulrich <josh.m.ulrich@gmail.com>
Repository: CRAN
Date/Publication: 2024-09-04 18:30:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 08:52:13 UTC; unix
Archs: microbenchmark.so.dSYM
